@@ -1,7 +1,6 @@
 import signal
 import psutil
-import sys
-from zenframe.util import print_to_stderr
+import os
 
 DESTRUCTORS = {}
 
@@ -31,14 +30,11 @@ def terminate_all_subprocess():
     for p in procs:
         p.terminate()
 
-    for p in procs:
-        p.wait()
-
 
 def interrupt_handler(a, b):
     invoke_destructors()
     terminate_all_subprocess()
-    sys.exit()
+    os._exit(0)
 
 
 def setup_interrupt_handlers():
